package betterquesting.client.gui2.editors.nbt;

import betterquesting.api.client.gui.misc.IVolatileScreen;
import betterquesting.api.misc.ICallback;
import betterquesting.api.utils.BigItemStack;
import betterquesting.api.utils.JsonHelper;
import betterquesting.api2.client.gui.GuiScreenCanvas;
import betterquesting.api2.client.gui.controls.PanelButton;
import betterquesting.api2.client.gui.controls.PanelButtonStorage;
import betterquesting.api2.client.gui.controls.PanelTextField;
import betterquesting.api2.client.gui.controls.filters.FieldFilterNumber;
import betterquesting.api2.client.gui.controls.filters.FieldFilterString;
import betterquesting.api2.client.gui.events.IPEventListener;
import betterquesting.api2.client.gui.events.PEventBroadcaster;
import betterquesting.api2.client.gui.events.PanelEvent;
import betterquesting.api2.client.gui.events.types.PEventButton;
import betterquesting.api2.client.gui.misc.GuiAlign;
import betterquesting.api2.client.gui.misc.GuiPadding;
import betterquesting.api2.client.gui.misc.GuiTransform;
import betterquesting.api2.client.gui.panels.CanvasEmpty;
import betterquesting.api2.client.gui.panels.CanvasTextured;
import betterquesting.api2.client.gui.panels.bars.PanelVScrollBar;
import betterquesting.api2.client.gui.panels.content.PanelItemSlot;
import betterquesting.api2.client.gui.panels.content.PanelLine;
import betterquesting.api2.client.gui.panels.content.PanelTextBox;
import betterquesting.api2.client.gui.panels.lists.CanvasItemDatabase;
import betterquesting.api2.client.gui.themes.presets.PresetColor;
import betterquesting.api2.client.gui.themes.presets.PresetLine;
import betterquesting.api2.client.gui.themes.presets.PresetTexture;
import betterquesting.api2.utils.QuestTranslation;
import net.minecraft.client.gui.GuiScreen;
import net.minecraft.entity.player.InventoryPlayer;
import net.minecraft.item.ItemStack;
import net.minecraft.nbt.NBTTagCompound;
import net.minecraft.util.StringUtils;
import net.minecraftforge.oredict.OreDictionary;
import org.lwjgl.input.Keyboard;
import org.lwjgl.util.vector.Vector4f;

/* loaded from: betterquesting_client_gui2_editors_nbt.jar:betterquesting/client/gui2/editors/nbt/GuiItemSelection.class */
public class GuiItemSelection extends GuiScreenCanvas implements IPEventListener, IVolatileScreen {
    private final ICallback<BigItemStack> callback;
    private BigItemStack itemStack;
    private PanelTextField<Integer> fieldSize;
    private PanelItemSlot itemPreview;
    private PanelButtonStorage<Integer> btnOre;

    public GuiItemSelection(GuiScreen parent, NBTTagCompound tag, ICallback<BigItemStack> callback) {
        this(parent, JsonHelper.JsonToItemStack(tag), callback);
    }

    public GuiItemSelection(GuiScreen parent, BigItemStack stack, ICallback<BigItemStack> callback) {
        super(parent);
        this.callback = callback;
        this.itemStack = stack;
    }

    public void initPanel() {
        super.initPanel();
        PEventBroadcaster.INSTANCE.register(this, PEventButton.class);
        Keyboard.enableRepeatEvents(true);
        CanvasTextured cvBackground = new CanvasTextured(new GuiTransform(GuiAlign.FULL_BOX, new GuiPadding(0, 0, 0, 0), 0), PresetTexture.PANEL_MAIN.getTexture());
        addPanel(cvBackground);
        cvBackground.addPanel(new PanelButton(new GuiTransform(GuiAlign.BOTTOM_CENTER, -100, -16, 200, 16, 0), 0, QuestTranslation.translate("gui.done", new Object[0])));
        PanelTextBox txTitle = new PanelTextBox(new GuiTransform(GuiAlign.TOP_EDGE, new GuiPadding(0, 16, 0, -32), 0), QuestTranslation.translate("betterquesting.title.select_item", new Object[0])).setAlignment(1);
        txTitle.setColor(PresetColor.TEXT_HEADER.getColor());
        cvBackground.addPanel(txTitle);
        CanvasEmpty cvRight = new CanvasEmpty(new GuiTransform(GuiAlign.HALF_RIGHT, new GuiPadding(8, 32, 16, 32), 0));
        cvBackground.addPanel(cvRight);
        CanvasItemDatabase cvDatabase = new CanvasItemDatabase(new GuiTransform(GuiAlign.FULL_BOX, new GuiPadding(0, 16, 8, 0), 0), 1);
        cvRight.addPanel(cvDatabase);
        PanelTextField<String> searchBox = new PanelTextField<>(new GuiTransform(GuiAlign.TOP_EDGE, new GuiPadding(0, 0, 8, -16), 0), "", FieldFilterString.INSTANCE);
        cvDatabase.getClass();
        searchBox.setCallback(cvDatabase::setSearchFilter).setWatermark("Search...");
        cvRight.addPanel(searchBox);
        PanelVScrollBar scEdit = new PanelVScrollBar(new GuiTransform(GuiAlign.RIGHT_EDGE, new GuiPadding(-8, 16, 0, 0), 0));
        cvDatabase.setScrollDriverY(scEdit);
        cvRight.addPanel(scEdit);
        CanvasEmpty cvTopLeft = new CanvasEmpty(new GuiTransform(new Vector4f(0.0f, 0.0f, 0.5f, 0.4f), new GuiPadding(16, 32, 8, 8), 0));
        cvBackground.addPanel(cvTopLeft);
        PanelTextBox txSelection = new PanelTextBox(new GuiTransform(GuiAlign.TOP_EDGE, new GuiPadding(0, 0, 0, -16), 0), QuestTranslation.translate("betterquesting.gui.selection", new Object[0]));
        txSelection.setColor(PresetColor.TEXT_MAIN.getColor());
        cvTopLeft.addPanel(txSelection);
        this.itemPreview = new PanelItemSlot(new GuiTransform(GuiAlign.TOP_LEFT, 0, 16, 36, 36, 0), 99, this.itemStack, false, true);
        cvTopLeft.addPanel(this.itemPreview);
        PanelTextBox txMulti = new PanelTextBox(new GuiTransform(GuiAlign.TOP_LEFT, 36, 20, 16, 12, 0), "x").setAlignment(1);
        txMulti.setColor(PresetColor.TEXT_MAIN.getColor());
        cvTopLeft.addPanel(txMulti);
        this.fieldSize = new PanelTextField<>(new GuiTransform(GuiAlign.TOP_EDGE, new GuiPadding(52, 16, 0, -32), 0), this.itemStack == null ? "1" : "" + this.itemStack.stackSize, FieldFilterNumber.INT);
        cvTopLeft.addPanel(this.fieldSize);
        this.fieldSize.setCallback(value -> {
            if (this.itemStack != null) {
                this.itemStack.stackSize = value.intValue();
            }
        });
        String oreName = "NONE";
        int oreIdx = -1;
        if (this.itemStack != null && !StringUtils.func_151246_b(this.itemStack.getOreDict())) {
            oreName = this.itemStack.getOreDict();
            int[] oreIds = OreDictionary.getOreIDs(this.itemStack.getBaseStack());
            int i = 0;
            while (true) {
                if (i >= oreIds.length) {
                    break;
                }
                if (!OreDictionary.getOreName(oreIds[i]).equalsIgnoreCase(oreName)) {
                    i++;
                } else {
                    oreIdx = i;
                    break;
                }
            }
        }
        this.btnOre = new PanelButtonStorage<>(new GuiTransform(GuiAlign.TOP_EDGE, new GuiPadding(52, 36, 24, -52), 0), 2, "Ore: " + oreName, Integer.valueOf(oreIdx));
        cvTopLeft.addPanel(this.btnOre);
        PanelButton btnWild = new PanelButton(new GuiTransform(GuiAlign.TOP_RIGHT, -16, 36, 16, 16, 0), 3, "*");
        btnWild.setClickAction(b -> {
            if (this.itemStack != null) {
                this.itemStack.getBaseStack().func_77964_b(32767);
                this.itemPreview.setStoredValue(this.itemStack);
            }
        });
        cvTopLeft.addPanel(btnWild);
        CanvasEmpty cvBottomLeft = new CanvasEmpty(new GuiTransform(new Vector4f(0.0f, 0.4f, 0.5f, 1.0f), new GuiPadding(16, 8, 8, 32), 0));
        cvBackground.addPanel(cvBottomLeft);
        PanelTextBox txInvo = new PanelTextBox(new GuiTransform(GuiAlign.TOP_EDGE, new GuiPadding(0, 0, 0, -16), 0), QuestTranslation.translate("container.inventory", new Object[0]));
        txInvo.setColor(PresetColor.TEXT_MAIN.getColor());
        cvBottomLeft.addPanel(txInvo);
        InventoryPlayer inventoryPlayer = this.field_146297_k.field_71439_g.field_71071_by;
        float iScale = Math.min(cvBottomLeft.getTransform().getWidth() / 162.0f, (cvBottomLeft.getTransform().getHeight() - 20) / 72.0f);
        int slotSize = (int) Math.floor(18.0f * iScale);
        for (int i2 = 0; i2 < 27; i2++) {
            int x = (i2 % 9) * slotSize;
            int y = ((i2 / 9) * slotSize) + 16;
            ItemStack tmp = inventoryPlayer.func_70301_a(i2 + 9);
            BigItemStack invoStack = tmp == null ? null : new BigItemStack(tmp);
            cvBottomLeft.addPanel(new PanelItemSlot(new GuiTransform(GuiAlign.TOP_LEFT, x, y, slotSize, slotSize, 0), 1, invoStack, true));
        }
        for (int i3 = 0; i3 < 9; i3++) {
            int x2 = (i3 % 9) * slotSize;
            ItemStack tmp2 = inventoryPlayer.func_70301_a(i3);
            BigItemStack invoStack2 = tmp2 == null ? null : new BigItemStack(tmp2);
            cvBottomLeft.addPanel(new PanelItemSlot(new GuiTransform(GuiAlign.TOP_LEFT, x2, 20 + (3 * slotSize), slotSize, slotSize, 0), 1, invoStack2, true));
        }
        GuiTransform guiTransform = new GuiTransform(GuiAlign.TOP_CENTER, 0, 32, 0, 0, 0);
        guiTransform.setParent(cvBackground.getTransform());
        GuiTransform guiTransform2 = new GuiTransform(GuiAlign.BOTTOM_CENTER, 0, -32, 0, 0, 0);
        guiTransform2.setParent(cvBackground.getTransform());
        PanelLine paLine0 = new PanelLine(guiTransform, guiTransform2, PresetLine.GUI_DIVIDER.getLine(), 1, PresetColor.GUI_DIVIDER.getColor(), 1);
        cvBackground.addPanel(paLine0);
    }

    public void onPanelEvent(PanelEvent event) {
        if (event instanceof PEventButton) {
            onButtonPress((PEventButton) event);
        }
    }

    private void onButtonPress(PEventButton event) {
        PanelButtonStorage button = event.getButton();
        if (button.getButtonID() == 0) {
            if (this.callback != null) {
                this.callback.setValue(this.itemStack);
            }
            this.field_146297_k.func_147108_a(this.parent);
            return;
        }
        if (button.getButtonID() == 1 && (button instanceof PanelButtonStorage)) {
            BigItemStack tmp = (BigItemStack) button.getStoredValue();
            if (tmp != null) {
                this.itemStack = tmp.copy();
                this.itemPreview.setStoredValue(this.itemStack);
                this.btnOre.setStoredValue(-1).setText("Ore: NONE");
                this.fieldSize.setText("" + this.itemStack.stackSize);
                return;
            }
            return;
        }
        if (button.getButtonID() == 2 && (button instanceof PanelButtonStorage) && this.itemStack != null) {
            int[] oreIds = OreDictionary.getOreIDs(this.itemStack.getBaseStack());
            int idx = ((Integer) button.getStoredValue()).intValue() + 1;
            if (idx >= oreIds.length || idx < 0) {
                this.itemStack.setOreDict("");
                button.setStoredValue(-1).setText("Ore: NONE");
                this.itemPreview.setStoredValue(this.itemStack);
            } else {
                this.itemStack.setOreDict(OreDictionary.getOreName(oreIds[idx]));
                button.setStoredValue(Integer.valueOf(idx)).setText("Ore: " + this.itemStack.getOreDict());
                this.itemPreview.setStoredValue(this.itemStack);
            }
        }
    }
}
